==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/si_LK.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "ගොනුවක් උඩුගත නොවුනි. නොහැඳිනු දෝෂයක්",
    "There is no error, the file uploaded with success" : "දෝෂයක් නොමැත. සාර්ථකව ගොනුව උඩුගත කෙරුණි",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "උඩුගත කළ ගොනුවේ විශාලත්වය HTML පෝරමයේ නියම කළ ඇති MAX_FILE_SIZE විශාලත්වයට වඩා වැඩිය",
    "The uploaded file was only partially uploaded" : "උඩුගත කළ ගොනුවේ කොටසක් පමණක් උඩුගත විය",
    "No file was uploaded" : "ගොනුවක් උඩුගත නොවුණි",
    "Missing a temporary folder" : "තාවකාලික ෆොල්ඩරයක් අතුරුදහන්",
    "Failed to write to disk" : "තැටිගත කිරීම අසාර්ථකයි",
    "Files" : "ගොනු",
    "Home" : "නිවස",
    "Upload cancelled." : "උඩුගත කිරීම අත් හරින්න ලදී",
    "File upload is in progress. Leaving the page now will cancel the upload." : "උඩුගතකිරීමක් සිදුවේ. පිටුව හැර යාමෙන් එය නැවතෙනු ඇත",
    "Rename" : "නැවත නම් කරන්න",
    "Delete" : "මකා දමන්න",
    "Unshare" : "නොබෙදු",
    "Download" : "බාන්න",
    "Select" : "තෝරන්න",
    "Error" : "දෝෂයක්",
    "Name" : "නම",
    "Size" : "ප්‍රමාණය",
    "Modified" : "වෙනස් කළ",
    "A new file or folder has been <strong>created</strong>" : "නව ගොනුවක් හෝ බහාලුමක් <strong> නිර්මාණය කර ඇත</ strong> ",
    "A file or folder has been <strong>changed</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>වෙනස්</strong> වී ඇත",
    "A file or folder has been <strong>deleted</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>මකා දමා</strong> ඇත",
    "A file or folder has been <strong>restored</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>ප්‍රතිස්ථාපනය</strong> කර ඇත",
    "File handling" : "ගොනු පරිහරණය",
    "Maximum upload size" : "උඩුගත කිරීමක උපරිම ප්‍රමාණය",
    "max. possible: " : "හැකි උපරිමය:",
    "Save" : "සුරකින්න",
    "Settings" : "සිටුවම්",
    "New" : "නව",
    "Text file" : "පෙළ ගොනුව",
    "Folder" : "ෆෝල්ඩරය",
    "Upload" : "උඩුගත කරන්න",
    "Cancel upload" : "උඩුගත කිරීම අත් හරින්න",
    "Upload too large" : "උඩුගත කිරීම විශාල වැඩිය",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ඔබ උඩුගත කිරීමට තැත් කරන ගොනු මෙම සේවාදායකයා උඩුගත කිරීමට ඉඩදී ඇති උපරිම ගොනු විශාලත්වයට වඩා වැඩිය",
    "Files are being scanned, please wait." : "ගොනු පරික්ෂා කෙරේ. මඳක් රැඳී සිටින්න"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/si_LK.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "ගොනුවක් උඩුගත නොවුනි. නොහැඳිනු දෝෂයක්",
    "There is no error, the file uploaded with success" : "දෝෂයක් නොමැත. සාර්ථකව ගොනුව උඩුගත කෙරුණි",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "උඩුගත කළ ගොනුවේ විශාලත්වය HTML පෝරමයේ නියම කළ ඇති MAX_FILE_SIZE විශාලත්වයට වඩා වැඩිය",
    "The uploaded file was only partially uploaded" : "උඩුගත කළ ගොනුවේ කොටසක් පමණක් උඩුගත විය",
    "No file was uploaded" : "ගොනුවක් උඩුගත නොවුණි",
    "Missing a temporary folder" : "තාවකාලික ෆොල්ඩරයක් අතුරුදහන්",
    "Failed to write to disk" : "තැටිගත කිරීම අසාර්ථකයි",
    "Files" : "ගොනු",
    "Home" : "නිවස",
    "Close" : "වසන්න",
    "Upload cancelled." : "උඩුගත කිරීම අත් හරින්න ලදී",
    "File upload is in progress. Leaving the page now will cancel the upload." : "උඩුගතකිරීමක් සිදුවේ. පිටුව හැර යාමෙන් එය නැවතෙනු ඇත",
    "Download" : "බාන්න",
    "Rename" : "නැවත නම් කරන්න",
    "Delete" : "මකා දමන්න",
    "Select" : "තෝරන්න",
    "Error" : "දෝෂයක්",
    "Name" : "නම",
    "Size" : "ප්‍රමාණය",
    "Modified" : "වෙනස් කළ",
    "New" : "නව",
    "Upload" : "උඩුගත කරන්න",
    "Text file" : "පෙළ ගොනුව",
    "Folder" : "ෆෝල්ඩරය",
    "A new file or folder has been <strong>created</strong>" : "නව ගොනුවක් හෝ බහාලුමක් <strong> නිර්මාණය කර ඇත</ strong> ",
    "A file or folder has been <strong>changed</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>වෙනස්</strong> වී ඇත",
    "A file or folder has been <strong>deleted</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>මකා දමා</strong> ඇත",
    "A file or folder has been <strong>restored</strong>" : "ගොනුවක් හෝ ෆෝල්ඩරයක් <strong>ප්‍රතිස්ථාපනය</strong> කර ඇත",
    "File handling" : "ගොනු පරිහරණය",
    "Maximum upload size" : "උඩුගත කිරීමක උපරිම ප්‍රමාණය",
    "max. possible: " : "හැකි උපරිමය:",
    "Save" : "සුරකින්න",
    "Settings" : "සිටුවම්",
    "Cancel upload" : "උඩුගත කිරීම අත් හරින්න",
    "Upload too large" : "උඩුගත කිරීම විශාල වැඩිය",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ඔබ උඩුගත කිරීමට තැත් කරන ගොනු මෙම සේවාදායකයා උඩුගත කිරීමට ඉඩදී ඇති උපරිම ගොනු විශාලත්වයට වඩා වැඩිය",
    "Files are being scanned, please wait." : "ගොනු පරික්ෂා කෙරේ. මඳක් රැඳී සිටින්න",
    "Upload cancelled." : "උඩුගත කිරීම අත් හරින්න ලදී"
},
"nplurals=2; plural=(n != 1);");
